/** @(#)compiler.h Created on: <30-Nov-2003 06:52:18 Z4303>
 *  Last Time-stamp: <30-Nov-2003 09:47:10 Z4303>
 *
 *  \file compiler.h
 *  \ingroup Build Environment
 *  \brief  All compiler specific information goes in this file.
 *
 *  By keeping all compiler related items in one place, it makes code
 *  easier to port to other compilers and architectures.
 *
 *  compiler.h is the only file allowed to contain CPU specific header file references. *
 *
 * Data Types:
 * Per MISRA guidelines all types must be 'typedef'ed.
 *
 *  Standard intrinsic types should not be used with in the code proper:
 *	bool, char, wchar_t, int, float, double, and
 *	for modifiers unsigned, signed, short and long.
 *
 * MISRA is the "Guidelines for the use of the C Language in Vehicle Based Software".
 * http://www.misra.org.uk
 *
 *
 *  The typedefs mandated by the C99 standard, are preferred
 *  over rolling our own typedefs.
 *
 * Include the standard header <stdint.h>/<inttypes.h> to define various integer types, and
 * related macros, with size constraints. Note that the definitions shown for
 * the types and macros are merely representative -- they can vary among
 * implementations.
 *
 */

/*lint -save -e755 -e756 Disable warning(s), this file only, global macro/typedef 'Symbol' (Location) not referenced */

#ifndef _COMPILER_H_
#define _COMPILER_H_ (1)

#if !defined(_BV)	/* Bit Value macro to hide details of bit shifts, makes code easier to read */
#define _BV(x) (1<<x)
#endif

typedef unsigned char  uint8_t;
typedef unsigned short uint16_t;

#include <ez8f6403.h> /* Include the specific CPU type we are building for in
			 this project */
#include "ez8bits.h"  /* Define proper macros to references the registers */

/* I like long names, not cryptic ones: */
#define DISABLE_INTERRUPTS() DI()
#define ENABLE_INTERRUPTS()  EI()

/*
 * No two compilers agree on how to designate constants in Flash memory.
 * Use these defines to make this code portable to other compilers,
 * and CPU variations.
 */

#define CONST        const
#define CONST_FLASH  const
#define FLASH_PREFIX rom
#define FLASH_SUFFIX
#define FLASH rom
#define PROGMEM

#ifndef FALSE
#define FALSE (0)
#endif

#ifndef TRUE
#define TRUE (!(FALSE))
#endif

#ifndef OFF
#define OFF (0)
#endif

#ifndef ON
#define ON (!(OFF))
#endif


#endif /* _COMPILER_H_ */

/*lint -restore */
