/** @(#)ez8bits.h Created on: <30-Nov-2003 06:57:05 Z4303>
 *  Last Time-stamp: <30-Nov-2003 07:29:52 Z4303>
 *
 *  \file ez8bits.h
 *  \brief  Define proper macros for the Z8 Enhanced! peripheral register map.
 *
 */

/*lint -save -e755 -e756 Disable warning(s), this file only, global macro/typedef 'Symbol' (Location) not referenced */

#ifndef _EZ8BITS_H_
#define _EZ8BITS_H_ (1)

/* Timer 0-3 Control Register (TxCTL)
 *
 * TEN Timer Enable
 *  0 = Timer is disabled.
 *  1 = Timer enabled to count.
 *
 * TPOL Timer Input/Output Polarity
 *  Operation of this bit is a function of the current operating mode of the timer.
 * 
 * BITS  7   6    5 4 3 2 1 0
 * FIELD TEN TPOL PRES  TMODE
 * RESET 0   0    0 0 0 0 0 0
 * ADDR F07H, F0FH, F17H, F1FH
 *
 * PRES Prescale value
 *  000 = Divide by 1
 *  001 = Divide by 2
 *  010 = Divide by 4
 *  011 = Divide by 8
 *  100 = Divide by 16
 *  101 = Divide by 32
 *  110 = Divide by 64
 *  111 = Divide by 128
 *
 * TMODE Timer mode
 *  000 = One-Shot mode
 *  001 = Continuous mode
 *  010 = Counter mode
 *  011 = PWM mode
 *  100 = Capture mode
 *  101 = Compare mode
 *  110 = Gated mode
 *  111 = Capture/Compare mode
 */
#define TEN    _BV(7) /* 0x80 1 = Timer Enable */
#define TPOL   _BV(6) /* 0x40 Timer Input/Output Polarity, depends on mode */
#define PRES2  _BV(5) /* 0x20 Prescale */
#define PRES1  _BV(4) /* 0x10 Prescale */
#define PRES0  _BV(3) /* 0x08 Prescale */
#define TMODE2 _BV(2) /* 0x04 Timer Mode */
#define TMODE1 _BV(1) /* 0x02 Timer Mode */
#define TMODE0 _BV(0) /* 0x01 Timer Mode */

#define TPRESCALE1   (0)
#define TPRESCALE2   (PRES0)
#define TPRESCALE4   (PRES1)
#define TPRESCALE8   (PRES1|PRES0)
#define TPRESCALE16  (PRES2)
#define TPRESCALE32  (PRES2|PRES0)
#define TPRESCALE64  (PRES2|PRES1)
#define TPRESCALE128 (PRES2|PRES1|PRES0)

#define TMODE_ONE_SHOT        (0)
#define TMODE_CONTINUOUS      (TMODE0)
#define TMODE_COUNTER         (TMODE1)
#define TMODE_PWM             (TMODE1|TMODE0)
#define TMODE_CAPTURE         (TMODE2)
#define TMODE_COMPARE         (TMODE2|TMODE0)
#define TMODE_GATED           (TMODE2|TMODE1)
#define TMODE_CAPTURE_COMPARE (TMODE2|TMODE1|TMODE0)

/*
 * IRQ1ENH[x] IRQ1ENL[x] Priority Description
 * 0 0 Disabled Disabled
 * 0 1 Level 1 Low
 * 1 0 Level 2 Nominal
 * 1 1 Level 3 High
 * where x indicates the register bits from 0 through 7.
 */

/* IRQ0 Enable High Bit Register (IRQ0ENH) */
#define T2ENH  _BV(7) /* 0x80 Timer 2 Interrupt Request Enable High Bit */
#define T1ENH  _BV(6) /* 0x40 Timer 1 Interrupt Request Enable High Bit */
#define T0ENH  _BV(5) /* 0x20 Timer 0 Interrupt Request Enable High Bit */
#define U0RENH _BV(4) /* 0x10 UART 0 Receive Interrupt Request Enable High Bit */
#define U0TENH _BV(3) /* 0x08 UART 0 Transmit Interrupt Request Enable High Bit */
#define I2CENH _BV(2) /* 0x04 I 2 C Interrupt Request Enable High Bit */
#define SPIENH _BV(1) /* 0x02 SPI Interrupt Request Enable High Bit */
#define ADCENH _BV(0) /* 0x01 ADC Interrupt Request Enable High Bit */

/* IRQ0 Enable Low Bit Register (IRQ0ENL) */
#define T2ENL  _BV(7) /* Timer 2 Interrupt Request Enable Low Bit */
#define T1ENL  _BV(6) /* Timer 1 Interrupt Request Enable Low Bit */
#define T0ENL  _BV(5) /* Timer 0 Interrupt Request Enable Low Bit */
#define U0RENL _BV(4) /* UART 0 Receive Interrupt Request Enable Low Bit */
#define U0TENL _BV(3) /* UART 0 Transmit Interrupt Request Enable Low Bit */
#define I2CENL _BV(2) /* I 2 C Interrupt Request Enable Low Bit */
#define SPIENL _BV(1) /* SPI Interrupt Request Enable Low Bit */
#define ADCENL _BV(0) /* ADC Interrupt Request Enable Low Bit */

/* IRQ1 Enable High Bit Register (IRQ1ENH): */
/* IRQ1 Enable Low Bit Register (IRQ1ENL) */
#define PAD7EN _BV(7) /* Port A or Port D Bit[x] Interrupt Request Enable High Bit */
#define PAD6EN _BV(6) /* Port A or Port D Bit[x] Interrupt Request Enable High Bit */
#define PAD5EN _BV(5) /* Port A or Port D Bit[x] Interrupt Request Enable High Bit */
#define PAD4EN _BV(4) /* Port A or Port D Bit[x] Interrupt Request Enable High Bit */
#define PAD3EN _BV(3) /* Port A or Port D Bit[x] Interrupt Request Enable High Bit */
#define PAD2EN _BV(2) /* Port A or Port D Bit[x] Interrupt Request Enable High Bit */
#define PAD1EN _BV(1) /* Port A or Port D Bit[x] Interrupt Request Enable High Bit */
#define PAD0EN _BV(0) /* Port A or Port D Bit[x] Interrupt Request Enable High Bit */

/* IRQ2 Enable High Bit Register (IRQ2ENH) */
#define T3ENH  _BV(7) /* Timer 3 Interrupt Request Enable High Bit */
#define U1RENH _BV(6) /* Receive Interrupt Request Enable High Bit */
#define U1TENH _BV(5) /* Transmit Interrupt Request Enable High Bit */
#define DMAENH _BV(4) /* Interrupt Request Enable High Bit */
#define C3ENH  _BV(3) /* Interrupt Request Enable High Bit */
#define C2ENH  _BV(2) /* Interrupt Request Enable High Bit */
#define C1ENH  _BV(1) /* Interrupt Request Enable High Bit */
#define C0ENH  _BV(0) /* Interrupt Request Enable High Bit */

/* IRQ2 Enable Low Bit Register (IRQ2ENL): */
#define T3ENL  _BV(7) /* Timer 3 Interrupt Request Enable Low Bit */
#define U1RENL _BV(6) /* UART 1 Receive Interrupt Request Enable Low Bit */
#define U1TENL _BV(5) /* UART 1 Transmit Interrupt Request Enable Low Bit */
#define DMAENL _BV(4) /* DMA Interrupt Request Enable Low Bit */
#define C3ENL  _BV(3) /*Port C3 Interrupt Request Enable Low Bit */
#define C2ENL  _BV(2) /* Port C2 Interrupt Request Enable Low Bit */
#define C1ENL  _BV(1) /* Port C1 Interrupt Request Enable Low Bit */
#define C0ENL  _BV(0) /* Port C0 Interrupt Request Enable Low Bit */

/* 
 * Interrupt Port Select Register (IRQPS)
 * 0 = PAx is used for the interrupt for PAx/PDx interrupt request.
 * 1 = PDx is used for the interrupt for PAx/PDx interrupt request.
 */
#define PAD7S _BV(7) /* PAx/PDx Selection */
#define PAD6S _BV(6) /* PAx/PDx Selection */
#define PAD5S _BV(5) /* PAx/PDx Selection */
#define PAD4S _BV(4) /* PAx/PDx Selection */
#define PAD3S _BV(3) /* PAx/PDx Selection */
#define PAD2S _BV(2) /* PAx/PDx Selection */
#define PAD1S _BV(1) /* PAx/PDx Selection */
#define PAD0S _BV(0) /* PAx/PDx Selection */

#endif /* _EZ8BITS_H_ */

/*lint -restore */
