/** @(#)hardware.h Created on: <30-Nov-2003 06:52:30 Z4303>
 *  Last Time-stamp: <30-Nov-2003 10:53:06 Z4303>
 *
 *  \file hardware.h
 *  \ingroup I/O
 *  \brief Anything that touches the physical hardware is defined in this file.
 *
 */

/*lint -save -e755 -e756 Disable warning(s), this file only, global macro/typedef 'Symbol' (Location) not referenced */

#ifndef _HARDWARE_H_
#define _HARDWARE_H_ (1)

/*
 * Localize declarations and space allocations to this header file.
 * Only the parent file will set DEFINE_SPACE_x, no other file will set it.
 * For example hardware.c will set DEFINE_SPACE_HARDWARE_H, no other file
 * including the hardware.h file will set it.
 *
 * This technique keeps both the declarations and the space definitions in this
 * single file.  The parent file will allocated space and all others will
 * reference this file with 'extern'.
 */
#ifdef  DEFINE_SPACE_HARDWARE_H
#define EXTERN_HARDWARE
#else
#define EXTERN_HARDWARE extern
#endif

EXTERN_HARDWARE uint16_t random_number_u16;

#define LED_DIGITS_MAX_DIGITS (4) /* There are four 5x7 dot matrix LEDs */
#define LED_DIGITS_MAX_ROWS   (7) /* There are seven rows of dots in the dot matrix LEDs */

#define LED_D4 _BV(6) /* ZDS-II D4 LED PE6 Clock */
#define LED_D3 _BV(5) /* ZDS-II D3 LED PE5 Clock */
#define LED_D2 _BV(7) /* ZDS-II D2 LED PG7 Clock */
#define LED_D1 _BV(7) /* ZDS-II D1 LED PE7 Clock */

#define LED_D4_CLOCK() {PEOUT &= (uint8_t) ~LED_D4, PEOUT |= LED_D4;}/* Data is
									latched on the rising edge of the clock */
#define LED_D3_CLOCK() {PEOUT &= (uint8_t) ~LED_D3, PEOUT |= LED_D3;}
#define LED_D2_CLOCK() {PGOUT &= (uint8_t) ~LED_D2, PGOUT |= LED_D2;}
#define LED_D1_CLOCK() {PEOUT &= (uint8_t) ~LED_D1, PEOUT |= LED_D1;}

#define LED1 _BV(0) /* ZDS-II DCD LED */
#define LED2 _BV(3) /* ZDS-II RX  LED */
#define LED3 _BV(2) /* ZDS-II DTR LED */
#define LED4 _BV(1) /* ZDS-II TX  LED */

#define LED1_ASSERT()   (PFOUT |= (uint8_t)  LED1)
#define LED1_DEASSERT() (PFOUT &= (uint8_t) ~LED1)

#define LED2_ASSERT()   (PFOUT |= (uint8_t)  LED2)
#define LED2_DEASSERT() (PFOUT &= (uint8_t) ~LED2)

#define LED3_ASSERT()   (PFOUT |= (uint8_t)  LED3)
#define LED3_DEASSERT() (PFOUT &= (uint8_t) ~LED3)

#define LED4_ASSERT()   (PFOUT |= (uint8_t)  LED4)
#define LED4_DEASSERT() (PFOUT &= (uint8_t) ~LED4)

#define BELL_ASSERT()	LED4_ASSERT()
#define BELL_DEASSERT() LED4_DEASSERT()

#define PF7 _BV(7)
#define PF6 _BV(6)

#define BUTTONS_IN (PFIN)
#define BUTTON_READY PF6
#define BUTTON_STOP  PF7

#define SW1_ASSERTED() (!(PFIN & PF7))
#define SW2_ASSERTED() (!(PFIN & PF6))

/* OUTPUT ACTIONS: */
#define LED2_TOGGLE() {if( PFIN & LED2 ){ LED2_DEASSERT(); } else { LED2_ASSERT(); }}

#define Example2_O_LED2_TOGGLE() LED2_TOGGLE()

#define Example3_O_LED1_ASSERT() LED1_ASSERT();
#define Example3_O_LED2_TOGGLE() LED2_TOGGLE()

#define REFLEX_GAME_O_GAME_OVER_OFF() LED1_DEASSERT()
#define REFLEX_GAME_O_GAME_OVER_ON()  LED1_ASSERT()
#define REFLEX_GAME_O_GO_OFF()        LED2_DEASSERT()
#define REFLEX_GAME_O_GO_ON()	      display_go();
#define REFLEX_GAME_O_TILT_OFF()      LED3_DEASSERT()
#define REFLEX_GAME_O_TILT_ON()	      display_tilt();

#if defined(__cplusplus) && __cplusplus
 extern "C" {
#endif

/* Prototypes for hardware.c; items that don't fit in #define's: */
void display_rdy( void );	/* Display " RDY" on 5x7 Display */
void display_go( void );	/* Display "  GO" on 5x7 Display */
void display_tilt( void );	/* Display "TILT" on 5x7 Display */
void init_timer2( void );	/* Initialize timer2 */

#if defined(__cplusplus) && __cplusplus
 }
#endif


#endif /* _HARDWARE_H_ */

/*lint -restore */
