/** @(#)debounce.c Created on: <30-Nov-2003 19:00:02 Z4303>
 *  Last Time-stamp: <30-Nov-2003 07:42:11 Z4303>
 *
 *  \file debounce.c
 *  \ingroup Inputs
 *  \brief  Debounces buttons
 *
 */

/*lint -save */

#include "includes.h"

#define  DEFINE_SPACE_DEBOUNCE_H (1) /**< Define space for this file */
#include "debounce.h"

/** \fn uint8_t debounce_buttons( uint8_t buttons )
 *
 *  This function debounces the incoming argument.
 *
 * It is assumed that there is some type of 'tick'
 * calling the debounce_button() function, or via
 * the main loop if the switches are 'clean' enough.
 *
 *	\param uint8_t Pattern to be debounced
 *	\returns uint8_t Debounced pattern.
 *
 */
uint8_t debounce_buttons( uint8_t buttons )
{
    /*lint -e(727) Info 727: Symbol 'but_current' & 'but_stable not explicitly initialized [C Start guarantees zero] */
    static uint8_t  but_current, but_stable;
    uint8_t but_changed, but_last;

    but_last    = but_current;
    but_current = (uint8_t) ~buttons; /* Invert the buttons so that "open" happens when we first press the button */
    but_changed = (but_current ^ but_stable) & (uint8_t) ~but_last;
    but_stable  = (but_stable & but_last) | (but_current & (uint8_t) ~but_last);

    return( but_stable & but_changed );/* Buttons recently "opened" will be stable & changed. */
}

/*lint -restore */
