/** @(#)hardware.c Created on: <30-Nov-2003 07:49:19 Z4303>
 *  Last Time-stamp: <30-Nov-2003 10:33:22 Z4303>
 *
 *  \file hardware.c
 *  \ingroup I/O
 *  \brief  This file contains items to complex to be in hardware.h, that touch the physical hardware.
 *
 */

/*lint -save */

#include <stdio.h> /* sprintf() */

#include "includes.h"

#define  DEFINE_SPACE_HARDWARE_H (1) /* Allocate space in this file; hardware.c */
#include "hardware.h"

#include "led_digits.h"
#include "reflex_game.h"

/*
 * Initialize Timer-2 for one-shot mode with prescaler=128,
 * used to light 'Bell' LED for ~500 mS.
 */
#pragma interrupt
void isr_timer2(void)
{
    DISABLE_INTERRUPTS();
    IRQ0ENH &= (uint8_t) ~T2ENH; /* Disable Timer2 Interrupts */
    IRQ0ENL &= (uint8_t) ~T2ENL;
    ENABLE_INTERRUPTS();

    BELL_DEASSERT(); /* Turn off the 'Bell' that has already been 'ringing' */

    /* No need to re-enable a one shot timer IRQ */
}

void init_timer2( void )
{
    SET_VECTOR(TIMER2, isr_timer2);  /* Pass the vector number and the ISR
				      * address to be placed into the interrupt
				      * table
				      */
}

/* Esterel OUTPUT ACTIONS: */
void REFLEX_GAME_O_DISPLAY( int reaction_time )
{
    uint8_t string[16];

    (void) sprintf( string, "%04d", reaction_time );
    led_digits_string_out( string );
}

void REFLEX_GAME_O_RING_BELL( void )
{
    BELL_ASSERT();		     /* IRQ time out will turn the LED off,
					when one-shot times out */

    T2CTL = 0x00;		     /* Disable timer */

    T2H   = 0x00;                    /* Timer High */
    T2L   = 0x00;	             /* Timer Low */
    T2CPH = (uint8_t) 0xFF;          /* Reload Compare High and Low */
    T2CPL = (uint8_t) 0xFF;          /* To get max time period */

    IRQ0ENH &= (uint8_t) ~T2ENH;    /* Set Timer2 for Level-1/Low priority */
    IRQ0ENL |= T2ENL;

    T2CTL  = (TEN|TPRESCALE128|TMODE_ONE_SHOT); /* Enable Timer */
}

/*
 * Return a number from one to 8191 representing mS.
 *
 * Do a really bad pseudo-random number implementation:
 */
int RANDOM()
{
    uint16_t psedo_random_u16;

    psedo_random_u16 = random_number_u16 & (8192-1);/* Give random time from zero to ~8 seconds */

    if( 0 == psedo_random_u16 )
	psedo_random_u16 = 1;

    return( psedo_random_u16 );/* Give random time from one to ~8 seconds */
}

/* Display the world TILT on the LED display, and light the Tilt LED: */
uint8_t tilt[] = "TILT";

void display_tilt( void )
{
    LED3_ASSERT();
    led_digits_string_out( tilt );
}

/* Display the world RDY on the LED display */
uint8_t rdy[] = " RDY";

void display_rdy( void )
{
    led_digits_string_out( rdy );
}

/* Display the world GO on the LED display */
uint8_t go[] = " GO ";

void display_go( void )
{
    LED2_ASSERT();
    led_digits_string_out( go );
}

/*lint -restore */
