/** @(#)led_digits.c Created on: <30-Nov-2003 06:54:42 Z4303>
 *  Last Time-stamp: <30-Nov-2003 09:39:45 Z4303>
 *
 *  \file led_digits.c
 *  \ingroup I/O
 *  \brief Displays character string on 5x7 LED matrix.
 *
 */

/*lint -save */

#include "includes.h"

#define  DEFINE_SPACE_LED_DIGITS_H (1) /* Allocate space in this file; led_digits.c */
#include "led_digits.h"

#include "hardware.h"

#include "led_matrix.h"

static uint8_t led_digits_row_array_u8[LED_DIGITS_MAX_DIGITS][LED_DIGITS_MAX_ROWS];
static uint8_t led_digits_row_u8;

/**
 * Refreshes the 5x7 LED display.
 * It is called from the timer ISR.
 */
void isr_led_digits_timer(void)
{
    if( OFF == isr_led_digits_timer_state_u8 )/* Don't waste time here if the display is off */
	return;

    if( ++led_digits_digit_u8 >= LED_DIGITS_MAX_DIGITS )/* Move a row down on the current digit */
	{
	    led_digits_digit_u8 = (uint8_t) 0;
	    if( ++led_digits_row_u8 >= LED_DIGITS_MAX_ROWS )
		{
		    led_digits_row_u8 = (uint8_t) 0; /* We reached the last
							row, rest back to top row */
		    PGOUT = 0x01;
		}
	    else
		{
		    PGOUT = (uint8_t) (PGOUT << 1);  /* Move to the next digit next time */
		}
	}

    PEOUT = led_digits_row_array_u8[ led_digits_digit_u8 ][ led_digits_row_u8 ];

    /* Zilog claims that else-if constructs are faster than switch/case. */

    if( (uint8_t) 3 == led_digits_digit_u8 )/* Clock one of the digits each time we are called */
	{
	    LED_D4_CLOCK();
	}
    else if( (uint8_t) 2 == led_digits_digit_u8 )
	{
	    LED_D3_CLOCK();
	}
    else if( (uint8_t) 1 == led_digits_digit_u8 )
	{
	    LED_D2_CLOCK();
	}
    else if( (uint8_t) 0 == led_digits_digit_u8 )
	{
	    LED_D1_CLOCK();
	}
}

/**
 * ZDS-II Board comes up with Light Up The World attitude.
 * 74HC273 should have been used.
 * Turn off all of the LEDs in the digits.
 * Interrupts should be off when this function is called.
 */
void led_digits_all_off(void)
{
    isr_led_digits_timer_state_u8 = OFF;

    PEDD   = 0x00;  /* Data Direction,            0 = Output Direction */
    PEAF   = 0x00;  /* Alternate Function,        0 = Normal/Follow DDx bit */
    PEOC   = 0x00;  /* Output Control,            1 = Open Drain */
    PEHDE  = 0x00;  /* High Drive Enable,         1 = High Current Drive */
    PESMRE = 0x00;  /* Stop Mode Recovery Enable, 1 = Stop Mode Recovery Source */
    PEOUT  = 0x1F;  /* Output,                    1 = Logical High Output */

    PGDD   = 0x00;  /* Data Direction,            0 = Output Direction */
    PGAF   = 0x00;  /* Alternate Function,        0 = Normal/Follow DDx bit */
    PGOC   = 0x00;  /* Output Control,            1 = Open Drain */
    PGHDE  = 0x00;  /* High Drive Enable,         1 = High Current Drive */
    PGSMRE = 0x00;  /* Stop Mode Recovery Enable, 1 = Stop Mode Recovery Source */
    PGOUT  = 0x00;  /* Output, Select top row     1 = Logical High Output */

    LED_D1_CLOCK(); /* Clock all of the digits to blank them */
    LED_D2_CLOCK();
    LED_D3_CLOCK();
    LED_D4_CLOCK();
}

/**
 * Display a string on the LED dot matrix display.
 * The string may be terminated with 0x00 or the high bit
 * of the last character being '1' (doesn't waste space with 'null').
 */
void led_digits_string_out( uint8_t *string )
{
    uint8_t chr_u8, digit_counter_u8, row_counter_u8, high_bit_ends_string_u8;

    high_bit_ends_string_u8 = FALSE;

    /*
     * Convert all the ASCII values in one frame to the raw row-data.
     */
    for( digit_counter_u8 = 0; digit_counter_u8 < LED_DIGITS_MAX_DIGITS; ++digit_counter_u8 )
	{
	    chr_u8 = *string++;

	    if( (uint8_t) 0x80 & chr_u8 )
		high_bit_ends_string_u8 = TRUE;

	    chr_u8 &= (uint8_t) 0x7F; /* Mask off potential high bit terminator */
	    chr_u8 -= (uint8_t) ' ';  /* Subtract out 'space' bias */

	    for( row_counter_u8 = 0; row_counter_u8 < LED_DIGITS_MAX_ROWS; ++row_counter_u8 )
		{
		    led_digits_row_array_u8[ digit_counter_u8 ][ row_counter_u8 ] = led_row_data[ chr_u8 ][ row_counter_u8 ];
		}

	    if( TRUE == high_bit_ends_string_u8 )
		break;/* for() */
	}

    isr_led_digits_timer_state_u8 = ON;
}

/*lint -restore */
