/** @(#)led_matrix.h Created on: <30-Nov-2003 08:19:16 Z4303>
 *  Last Time-stamp: <30-Nov-2003 09:49:17 Z4303>
 *
 *  \file led_matrix.h
 *  \ingroup I/O
 *  \brief Row data for 5x7 LED matrix, for the 95 printable ASCII characters.
 *
 *  This file is based off of new_matrix.h from Zilog Application note AN144.
 *  It had no restrictive copyrights, unlike the other files of AN144.
 *
 *	 == === === ==   == === ==     == === =   === === ===
 *        0 00h NUL ^@   32 20h SP     64 40h @    96 60h `
 *	  1 01h SOH ^A   33 21h !      65 41h A    97 61h a
 *	  2 02h STX ^B   34 22h "      66 42h B    98 62h b
 *	  3 03h ETX ^C   35 23h #      67 43h C    99 63h c
 *	  4 04h EOT ^D   36 24h $      68 44h D   100 64h d
 *	  5 05h ENQ ^E   37 25h %      69 45h E   101 65h e
 *	  6 06h ACK ^F   38 26h &      70 46h F   102 66h f
 *	  7 07h BEL ^G   39 27h '      71 47h G   103 67h g
 *	  8 08h BS  ^H   40 28h (      72 48h H   104 68h h
 *	  9 09h HT  ^I   41 29h )      73 49h I   105 69h i
 *	 10 0Ah LF  ^J   42 2Ah *      74 4Ah J   106 6Ah j
 *	 11 0Bh VT  ^K   43 2Bh +      75 4Bh K   107 6Bh k
 *	 12 0Ch FF  ^L   44 2Ch ,      76 4Ch L   108 6Ch l
 *	 13 0Dh CR  ^M   45 2Dh -      77 4Dh M   109 6Dh m
 *	 14 0Eh SO  ^N   46 2Eh .      78 4Eh N   110 6Eh n
 *	 15 0Fh SI  ^O   47 2Fh /      79 4Fh O   111 6Fh o
 *	 -- --- --- --   -- --- --     -- --- -   --- --- ---
 *	 16 10h DLE ^P   48 30h 0      80 50h P   112 70h p
 *	 17 11h DC1 ^Q   49 31h 1      81 51h Q   113 71h q
 *	 18 12h DC2 ^R   50 32h 2      82 52h R   114 72h r
 *	 19 13h DC3 ^S   51 33h 3      83 53h S   115 73h s
 *	 20 14h DC4 ^T   52 34h 4      84 54h T   116 74h t
 *	 21 15h NAK ^U   53 35h 5      85 55h U   117 75h u
 *	 22 16h SYN ^V   54 36h 6      86 56h V   118 76h v
 *	 23 17h ETB ^W   55 37h 7      87 57h W   119 77h w
 *	 24 18h CAN ^X   56 38h 8      88 58h X   120 78h x
 *	 25 19h EM  ^Y   57 39h 9      89 59h Y   121 79h y
 *	 26 1Ah SUB ^Z   58 3Ah :      90 5Ah Z   122 7Ah z
 *	 27 1Bh ESC ^[   59 3Bh ;      91 5Bh [   123 7Bh {
 *	 28 1Ch FS  ^\   60 3Ch <      92 5Ch \   124 7Ch |
 *	 29 1Dh GS  ^]   61 3Dh =      93 5Dh ]   125 7Dh }
 *	 30 1Eh RS  ^^   62 3Eh >      94 5Eh ^   126 7Eh ~
 * 	 31 1Fh US  ^_   63 3Fh ?      95 5Fh _   127 7Fh DEL
 *	 == === === ==   == === ==     == === =   === === ===
 *
 */

/*lint -save -e755 -e756 Disable warning(s), this file only, global macro/typedef 'Symbol' (Location) not referenced */

#ifndef _LED_MATRIX_H_
#define _LED_MATRIX_H_ (1)

/* Place the table in Flash memory.  Use macros because no two compilers
 * aggree on how to designate constatns in Flash.
 */
CONST_FLASH FLASH_PREFIX uint8_t FLASH_SUFFIX led_row_data[][7] = PROGMEM {
    { 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F }, /* 0x20 [SPACE] */
    { 0x13, 0x13, 0x13, 0x13, 0x13, 0x1F, 0x13 }, /* 0x21 ! */
    { 0x15, 0x15, 0x15, 0x1F, 0x1F, 0x1F, 0x1F }, /* 0x22 " */
    { 0x15, 0x15, 0x00, 0x15, 0x00, 0x15, 0x15 }, /* 0x23 # */
    { 0x1B, 0x10, 0x0B, 0x11, 0x1A, 0x01, 0x1B }, /* 0x24 $ */
    { 0x07, 0x06, 0x1D, 0x1B, 0x17, 0x0C, 0x1C }, /* 0x25 % */
    { 0x13, 0x0D, 0x0B, 0x17, 0x0A, 0x0D, 0x12 }, /* 0x26 & */
    { 0x13, 0x1B, 0x17, 0x1F, 0x1F, 0x1F, 0x1F }, /* 0x27 ' */
    { 0x1D, 0x1B, 0x17, 0x17, 0x17, 0x1B, 0x1D }, /* 0x28 ( */
    { 0x17, 0x1B, 0x1D, 0x1D, 0x1D, 0x1B, 0x17 }, /* 0x29 ) */
    { 0x1F, 0x1B, 0x0A, 0x11, 0x0A, 0x1B, 0x1F }, /* 0x2A * */
    { 0x1F, 0x1B, 0x1B, 0x00, 0x1B, 0x1B, 0x1F }, /* 0x2B + */
    { 0x1F, 0x1F, 0x1F, 0x1F, 0x13, 0x1B, 0x17 }, /* 0x2C , */
    { 0x1F, 0x1F, 0x1F, 0x00, 0x1F, 0x1F, 0x1F }, /* 0x2D - */
    { 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x13, 0x13 }, /* 0x2E . */
    { 0x1F, 0x1E, 0x1D, 0x1B, 0x17, 0x0F, 0x1F }, /* 0x2F / */

    { 0x11, 0x0E, 0x0C, 0x0A, 0x06, 0x0E, 0x11 }, /* 0x30 0 */
    { 0x1B, 0x13, 0x1B, 0x1B, 0x1B, 0x1B, 0x11 }, /* 0x31 1 */
    { 0x11, 0x0E, 0x1E, 0x1D, 0x1B, 0x17, 0x00 }, /* 0x32 2 */
    { 0x11, 0x0E, 0x1E, 0x11, 0x1E, 0x0E, 0x11 }, /* 0x33 3 */
    { 0x1D, 0x19, 0x15, 0x0D, 0x00, 0x1D, 0x1D }, /* 0x34 4 */
    { 0x00, 0x0F, 0x0F, 0x01, 0x1E, 0x0E, 0x11 }, /* 0x35 5 */
    { 0x11, 0x0E, 0x0F, 0x01, 0x0E, 0x0E, 0x11 }, /* 0x36 6 */
    { 0x00, 0x0E, 0x1E, 0x1D, 0x1B, 0x1B, 0x1B }, /* 0x37 7 */
    { 0x11, 0x0E, 0x0E, 0x11, 0x0E, 0x0E, 0x11 }, /* 0x38 8 */
    { 0x11, 0x0E, 0x0E, 0x10, 0x1E, 0x0E, 0x11 }, /* 0x39 9 */

    { 0x1F, 0x13, 0x13, 0x1F, 0x13, 0x13, 0x1F }, /* 0x3A : */
    { 0x1F, 0x13, 0x13, 0x1F, 0x13, 0x1B, 0x17 }, /* 0x3B ; */
    { 0x1D, 0x1B, 0x17, 0x0F, 0x17, 0x1B, 0x1D }, /* 0x3C < */
    { 0x1F, 0x1F, 0x00, 0x1F, 0x00, 0x1F, 0x1F }, /* 0x3D = */
    { 0x17, 0x1B, 0x1D, 0x1E, 0x1D, 0x1B, 0x17 }, /* 0x3E > */
    { 0x11, 0x0E, 0x1E, 0x1D, 0x1B, 0x1F, 0x1B }, /* 0x3F ? */

    { 0x11, 0x0E, 0x1E, 0x12, 0x0A, 0x0A, 0x11 }, /* 0x40 @ */
    { 0x1B, 0x15, 0x0E, 0x00, 0x0E, 0x0E, 0x0E }, /* 0x41 A */
    { 0x01, 0x0E, 0x0E, 0x01, 0x0E, 0x0E, 0x01 }, /* 0x42 B */
    { 0x11, 0x0E, 0x0F, 0x0F, 0x0F, 0x0E, 0x11 }, /* 0x43 C */
    { 0x01, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x01 }, /* 0x44 D */
    { 0x00, 0x0F, 0x0F, 0x01, 0x0F, 0x0F, 0x00 }, /* 0x45 E */
    { 0x00, 0x0F, 0x0F, 0x01, 0x0F, 0x0F, 0x0F }, /* 0x46 F */
    { 0x11, 0x0E, 0x0F, 0x08, 0x0E, 0x0E, 0x10 }, /* 0x47 G */
    { 0x0E, 0x0E, 0x0E, 0x00, 0x0E, 0x0E, 0x0E }, /* 0x48 H */
    { 0x11, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x11 }, /* 0x49 I */
    { 0x1E, 0x1E, 0x1E, 0x1E, 0x0E, 0x0E, 0x11 }, /* 0x4A J */
    { 0x0E, 0x0D, 0x0B, 0x07, 0x0B, 0x0D, 0x0E }, /* 0x4B K */
    { 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x00 }, /* 0x4C L */
    { 0x0E, 0x04, 0x0A, 0x0A, 0x0E, 0x0E, 0x0E }, /* 0x4D M */
    { 0x0E, 0x06, 0x0A, 0x0C, 0x0E, 0x0E, 0x0E }, /* 0x4E N */
    { 0x11, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x11 }, /* 0x4F O */
    { 0x01, 0x0E, 0x0E, 0x01, 0x0F, 0x0F, 0x0F }, /* 0x50 P */
    { 0x11, 0x0E, 0x0E, 0x0E, 0x0A, 0x0D, 0x12 }, /* 0x51 Q */
    { 0x01, 0x0E, 0x0E, 0x01, 0x0E, 0x0E, 0x0E }, /* 0x52 R */
    { 0x11, 0x0E, 0x0F, 0x11, 0x1E, 0x0E, 0x11 }, /* 0x53 S */
    { 0x00, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B }, /* 0x54 T */
    { 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x11 }, /* 0x55 U */
    { 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x15, 0x1B }, /* 0x56 V */
    { 0x0E, 0x0E, 0x0E, 0x0A, 0x0A, 0x0A, 0x15 }, /* 0x57 W */
    { 0x0E, 0x0E, 0x15, 0x1B, 0x15, 0x0E, 0x0E }, /* 0x58 X */
    { 0x0E, 0x0E, 0x15, 0x1B, 0x1B, 0x1B, 0x1B }, /* 0x59 Y */
    { 0x00, 0x1E, 0x1D, 0x1B, 0x17, 0x0F, 0x00 }, /* 0x5A Z */

    { 0x03, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x03 }, /* 0x5B [ */
    { 0x1F, 0x0F, 0x17, 0x1B, 0x1D, 0x1E, 0x1F }, /* 0x5C \ */
    { 0x11, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x11 }, /* 0x5D ] */
    { 0x1B, 0x15, 0x0E, 0x1F, 0x1F, 0x1F, 0x1F }, /* 0x5E ^ */
    { 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x00 }, /* 0x5F _ */

    { 0x17, 0x1B, 0x1D, 0x1F, 0x1F, 0x1F, 0x1F }, /* 0x60 ` */
    { 0x1F, 0x1F, 0x11, 0x1E, 0x10, 0x0E, 0x10 }, /* 0x61 a */
    { 0x0F, 0x0F, 0x09, 0x06, 0x0E, 0x0E, 0x01 }, /* 0x62 b */
    { 0x1F, 0x1F, 0x11, 0x0F, 0x0F, 0x0E, 0x11 }, /* 0x63 c */
    { 0x1E, 0x1E, 0x12, 0x0C, 0x0E, 0x0E, 0x10 }, /* 0x64 d */
    { 0x1F, 0x1F, 0x11, 0x0E, 0x00, 0x0F, 0x11 }, /* 0x65 e */
    { 0x19, 0x16, 0x17, 0x03, 0x17, 0x17, 0x17 }, /* 0x66 f */
    { 0x1F, 0x10, 0x0E, 0x0E, 0x10, 0x1E, 0x11 }, /* 0x67 g */
    { 0x0F, 0x0F, 0x09, 0x06, 0x0E, 0x0E, 0x0E }, /* 0x68 h */
    { 0x1B, 0x1F, 0x13, 0x1B, 0x1B, 0x1B, 0x11 }, /* 0x69 i */
    { 0x1D, 0x1F, 0x19, 0x1D, 0x1D, 0x0D, 0x13 }, /* 0x6A j */
    { 0x0F, 0x0F, 0x0D, 0x0B, 0x07, 0x0B, 0x0D }, /* 0x6B k */
    { 0x13, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x11 }, /* 0x6C l */
    { 0x1F, 0x1F, 0x05, 0x0A, 0x0A, 0x0E, 0x0E }, /* 0x6D m */
    { 0x1F, 0x1F, 0x09, 0x06, 0x0E, 0x0E, 0x0E }, /* 0x6E n */
    { 0x1F, 0x1F, 0x11, 0x0E, 0x0E, 0x0E, 0x11 }, /* 0x6F o */
    { 0x1F, 0x1F, 0x01, 0x0E, 0x01, 0x0F, 0x0F }, /* 0x70 p */
    { 0x1F, 0x1F, 0x12, 0x0C, 0x10, 0x1E, 0x1E }, /* 0x71 q */
    { 0x1F, 0x1F, 0x09, 0x06, 0x0F, 0x0F, 0x0F }, /* 0x72 r */
    { 0x1F, 0x1F, 0x11, 0x0F, 0x11, 0x1E, 0x01 }, /* 0x73 s */
    { 0x17, 0x17, 0x03, 0x17, 0x17, 0x16, 0x19 }, /* 0x74 t */
    { 0x1F, 0x1F, 0x0E, 0x0E, 0x0E, 0x0C, 0x12 }, /* 0x75 u */
    { 0x1F, 0x1F, 0x0E, 0x0E, 0x0E, 0x15, 0x1B }, /* 0x76 v */
    { 0x1F, 0x1F, 0x0E, 0x0A, 0x0A, 0x0A, 0x15 }, /* 0x77 w */
    { 0x1F, 0x1F, 0x0E, 0x15, 0x1B, 0x15, 0x0E }, /* 0x78 x */
    { 0x1F, 0x1F, 0x0E, 0x0E, 0x10, 0x1E, 0x11 }, /* 0x79 y */
    { 0x1F, 0x1F, 0x00, 0x1D, 0x1B, 0x17, 0x00 }, /* 0x7A z */

    { 0x1D, 0x1B, 0x1B, 0x17, 0x1B, 0x1B, 0x1D }, /* 0x7B { */
    { 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B }, /* 0x7C | */
    { 0x17, 0x1B, 0x1B, 0x1D, 0x1B, 0x1B, 0x17 }, /* 0x7D } */
    { 0x1F, 0x1F, 0x17, 0x0A, 0x1D, 0x1F, 0x1F }, /* 0x7E ~ */
    { 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 }  /* 0x7F DEL ALL On */
};

#endif /* _LED_MATRIX_H_ */

/*lint -restore */
